@@ -28,23 +28,19 @@ import datetime
 import six
 
 from sahara.conductor import objects
-from sahara import exceptions as ex
-from sahara.i18n import _
-from sahara.service.edp import s3_common
 from sahara.swift import swift_helper
 from sahara.utils import types
 
 
 def wrap(resource_class):
-    """A decorator wraps dict returned by a given function into a Resource."""
+    """A decorator which wraps dict returned by a given function into
+    a Resource.
+    """
 
     def decorator(func):
         def handle(*args, **kwargs):
             ret = func(*args, **kwargs)
-            if isinstance(ret, types.Page):
-                return types.Page([resource_class(el) for el in ret],
-                                  ret.prev, ret.next)
-            elif isinstance(ret, list):
+            if isinstance(ret, list):
                 return [resource_class(el) for el in ret]
             elif ret:
                 return resource_class(ret)
@@ -57,9 +53,8 @@ def wrap(resource_class):
 
 
 class Resource(types.FrozenDict):
-    """Represents dictionary as an immutable object.
-
-    Enhancing it with back references and helper methods.
+    """Represents dictionary as an immutable object, enhancing it with
+    back references and helper methods.
 
     For instance, the following dictionary:
     {'first': {'a': 1, 'b': 2}, 'second': [1,2,3]}
@@ -92,7 +87,7 @@ class Resource(types.FrozenDict):
     def __init__(self, dct):
         super(Resource, self).__setattr__('_initial_dict', dct)
         newdct = dict()
-        for refname, entity in six.iteritems(dct):
+        for refname, entity in dct.iteritems():
             newdct[refname] = self._wrap_entity(refname, entity)
 
         super(Resource, self).__init__(newdct)
@@ -120,7 +115,7 @@ class Resource(types.FrozenDict):
         elif self._is_passthrough_type(entity):
             return entity
         else:
-            raise TypeError(_("Unsupported type: %s") % type(entity).__name__)
+            raise TypeError("Unsupported type: %s" % type(entity).__name__)
 
     def _wrap_list(self, refname, lst):
         newlst = [self._wrap_entity(refname, entity) for entity in lst]
@@ -148,7 +143,7 @@ class Resource(types.FrozenDict):
 
     def _to_dict(self, backref):
         dct = dict()
-        for refname, entity in six.iteritems(self):
+        for refname, entity in self.iteritems():
             if refname != backref and refname not in self._filter_fields:
                 childs_backref = None
                 if refname in self._children:
@@ -174,7 +169,7 @@ class Resource(types.FrozenDict):
         return self[item]
 
     def __setattr__(self, *args):
-        raise ex.FrozenClassError(self)
+        raise types.FrozenClassError(self)
 
 
 class NodeGroupTemplateResource(Resource, objects.NodeGroupTemplate):
@@ -182,15 +177,7 @@ class NodeGroupTemplateResource(Resource, objects.NodeGroupTemplate):
 
 
 class InstanceResource(Resource, objects.Instance):
-    _filter_fields = ['tenant_id', 'node_group_id', "volumes"]
-
-    @property
-    def cluster_id(self):
-        return self.node_group.cluster_id
-
-    @property
-    def cluster(self):
-        return self.node_group.cluster
+    _filter_fields = ['tenant_id', 'node_group_id']
 
 
 class NodeGroupResource(Resource, objects.NodeGroup):
@@ -199,8 +186,8 @@ class NodeGroupResource(Resource, objects.NodeGroup):
         'node_group_template': (NodeGroupTemplateResource, None)
     }
 
-    _filter_fields = ['tenant_id', 'cluster_id', 'cluster_template_id',
-                      'image_username', 'open_ports']
+    _filter_fields = ['id', 'tenant_id', 'cluster_id', 'cluster_template_id',
+                      'image_username']
 
 
 class ClusterTemplateResource(Resource, objects.ClusterTemplate):
@@ -211,58 +198,18 @@ class ClusterTemplateResource(Resource, objects.ClusterTemplate):
     }
 
 
-class ClusterHealthCheckResource(Resource, objects.ClusterHealthCheck):
-    _resource_name = 'cluster_health_check'
-
-
-class ClusterVerificationResource(Resource, objects.ClusterVerification):
-    _resource_name = 'cluster_verification'
-    _children = {
-        'checks': (ClusterHealthCheckResource, 'verification')
-    }
-
-
 class ClusterResource(Resource, objects.Cluster):
-
-    def sanitize_cluster_configs(self, cluster_configs):
-        if 'proxy_configs' in cluster_configs:
-            del cluster_configs['proxy_configs']
-        return cluster_configs
-
     _resource_name = 'cluster'
 
     _children = {
         'node_groups': (NodeGroupResource, 'cluster'),
-        'cluster_template': (ClusterTemplateResource, None),
-        'verification': (ClusterVerificationResource, 'cluster')
+        'cluster_template': (ClusterTemplateResource, None)
     }
 
-    _filter_fields = ['management_private_key', 'extra', 'rollback_info',
-                      'sahara_info']
-    _sanitize_fields = {'cluster_configs': sanitize_cluster_configs}
+    _filter_fields = ['management_private_key', 'extra']
 
 
-class ImageResource(Resource, objects.Image):
-
-    _resource_name = 'image'
-
-    @property
-    def dict(self):
-        return self.to_dict()
-
-    @property
-    def wrapped_dict(self):
-        return {'image': self.dict}
-
-    def _sanitize_image_properties(self, image_props):
-        if 'links' in image_props:
-            del image_props['links']
-        return image_props
-
-    _sanitize_fields = {'links': _sanitize_image_properties}
-
-
-# EDP Resources
+##EDP Resources
 
 class DataSource(Resource, objects.DataSource):
     _resource_name = "data_source"
@@ -278,15 +225,6 @@ class JobExecution(Resource, objects.JobExecution):
                 configs[swift_helper.HADOOP_SWIFT_USERNAME] = ""
             if swift_helper.HADOOP_SWIFT_PASSWORD in configs:
                 configs[swift_helper.HADOOP_SWIFT_PASSWORD] = ""
-            if s3_common.S3_ACCESS_KEY_CONFIG in configs:
-                configs[s3_common.S3_ACCESS_KEY_CONFIG] = ""
-            if s3_common.S3_SECRET_KEY_CONFIG in configs:
-                configs[s3_common.S3_SECRET_KEY_CONFIG] = ""
-
-        if 'trusts' in job_configs:
-            del job_configs['trusts']
-        if 'proxy_configs' in job_configs:
-            del job_configs['proxy_configs']
         return job_configs
 
     def sanitize_info(self, info):
@@ -300,7 +238,6 @@ class JobExecution(Resource, objects.JobExecution):
     _filter_fields = ['extra']
     _sanitize_fields = {'job_configs': sanitize_job_configs,
                         'info': sanitize_info}
-    # TODO(egafford): Sanitize interface ("secret" bool field on job args?)
 
 
 class JobBinary(Resource, objects.JobBinary):
